==> apache-james-imap-0.2.1-source-release.zip: apache-james-imap-0.2.1/message/src/test/java/org/apache/james/imap/encode/base/ByteImapResponseWriter.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.imap.encode.base;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.WritableByteChannel;

import org.apache.james.imap.api.ImapConstants;
import org.apache.james.imap.encode.ImapResponseWriter;
import org.apache.james.imap.message.response.Literal;

/**
 * Class providing methods to send response messages from the server to the
 * client.
 */
public class ByteImapResponseWriter implements ImapConstants, ImapResponseWriter {


    private ByteArrayOutputStream out;
    private WritableByteChannel channel;


    public ByteImapResponseWriter() {
        clear();
    }

    public byte[] getBytes() throws Exception {
        out.flush();
        return out.toByteArray();
    }
    
    public void clear() {
        this.out = new ByteArrayOutputStream();
        channel = Channels.newChannel(out);
    }

    public void write(Literal literal) throws IOException {
        literal.writeTo(channel);
    }
    public void write(ByteBuffer buffer) throws IOException {
        while (channel.write(buffer) > 0) { // NOPMD false positive
            // Write all
        }
    }
}

==> apache-james-imap-0.3-source-release.zip: apache-james-imap-0.3/message/src/test/java/org/apache/james/imap/encode/base/ByteImapResponseWriter.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.imap.encode.base;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

import org.apache.james.imap.api.ImapConstants;
import org.apache.james.imap.encode.ImapResponseWriter;
import org.apache.james.imap.message.response.Literal;

/**
 * Class providing methods to send response messages from the server to the
 * client.
 */
public class ByteImapResponseWriter implements ImapConstants, ImapResponseWriter {


    private ByteArrayOutputStream out;


    public ByteImapResponseWriter() {
        clear();
    }

    public byte[] getBytes() throws Exception {
        out.flush();
        return out.toByteArray();
    }
    
    public String getString() throws Exception {
    	return new String(getBytes());
    }
    
    public void clear() {
        this.out = new ByteArrayOutputStream();
    }

    public void write(Literal literal) throws IOException {
        InputStream in = null;
        try {
            in = literal.getInputStream();

            byte[] buffer = new byte[1024];
            for (int len; (len = in.read(buffer)) != -1;) {
                out.write(buffer, 0, len);
            }
        } finally {
            if (in != null) {
                in.close();
            }
        }
    }

    @Override
    public void write(byte[] buffer) throws IOException {
        out.write(buffer);
    }

}
